==> haskell-commutative-semigroups-0.1.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commutative-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commutative-semigroups
version:              0.1.0.1
visibility:           public
id:                   commutative-semigroups-0.1.0.1-IUFcGU4VCJzC1jgHpr3UMz
key:                  commutative-semigroups-0.1.0.1-IUFcGU4VCJzC1jgHpr3UMz
license:              BSD-3-Clause
copyright:
    Copyright (C) 2013 Nathan van Doorn, 2021–2022 Obsidian Systems LLC

maintainer:           maintainer@obsidian.systems
author:               Nathan "Taneb" van Doorn
synopsis:             Commutative semigroups
description:
    A commutative semigroup is a semigroup where the order of arguments to mappend does not matter.

category:             Algebra, Data, Math
abi:                  ca3b3297a203f6facbb4fdf099066f39
exposed:              True
exposed-modules:
    Data.Semigroup.Commutative Numeric.Product.Commutative

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/commutative-semigroups-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/commutative-semigroups-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commutative-semigroups
hs-libraries:         HScommutative-semigroups-0.1.0.1-IUFcGU4VCJzC1jgHpr3UMz
depends:              base-4.15.1.0 containers-0.6.4.1
haddock-interfaces:
    /usr/share/doc/haskell-commutative-semigroups/html/commutative-semigroups.haddock

haddock-html:         /usr/share/doc/haskell-commutative-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commutative-semigroups-0.1.0.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commutative-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commutative-semigroups
version:              0.1.0.2
visibility:           public
id:                   commutative-semigroups-0.1.0.2-8CiacxSTdcD4npFC3i68Vm
key:                  commutative-semigroups-0.1.0.2-8CiacxSTdcD4npFC3i68Vm
license:              BSD-3-Clause
copyright:
    Copyright (C) 2013 Nathan van Doorn, 2021–2022 Obsidian Systems LLC

maintainer:           maintainer@obsidian.systems
author:               Nathan "Taneb" van Doorn
synopsis:             Commutative semigroups
description:
    A commutative semigroup is a semigroup where the order of arguments to mappend does not matter.

category:             Algebra, Data, Math
abi:                  be1e14a6db55648c7ee96c7a6bbd73cf
exposed:              True
exposed-modules:
    Data.Semigroup.Commutative Numeric.Product.Commutative

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/commutative-semigroups-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/commutative-semigroups-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commutative-semigroups
hs-libraries:         HScommutative-semigroups-0.1.0.2-8CiacxSTdcD4npFC3i68Vm
depends:              base-4.15.1.0 containers-0.6.4.1
haddock-interfaces:
    /usr/share/doc/haskell-commutative-semigroups/html/commutative-semigroups.haddock

haddock-html:         /usr/share/doc/haskell-commutative-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
